@@ -8,7 +8,7 @@ package Sumu::Perl::Modules;
 
 =head1 VERSION
 
-version 0.4.7
+version 0.4.8
 
 =head2 SYNOPSIS
 
@@ -73,13 +73,13 @@ use warnings;
 
 =head2 our VERSION
 
-    our $VERSION = '0.4.7'
+    our $VERSION = '0.4.8'
 
     This version number is updated automatically!
 
 =cut
 
-our $VERSION = '0.4.7';
+our $VERSION = '0.4.8';
 
 
 =head2 Internals
@@ -223,7 +223,7 @@ sub _dirs  {
     my $module = $in{module};
     chomp $module; 
 
-    $module =~ s!\\!\/!g;
+    #$module =~ s!\\!\/!g;
 
     #
     my @mod_dirs = $inst->directories("$module");
@@ -296,7 +296,7 @@ sub _doc {
     my $module = $in{module};
         chomp $module;
 
-    $module =~ s!\\!\/!g;
+    #$module =~ s!\\!\/!g;
 
     if ( -f "$module" ) {
         if ( open( my $FILE, "<", "$module" ) ) {
@@ -311,10 +311,10 @@ sub _doc {
             }
             close $FILE;
         } else {
-            $error .= qq{Unable to open module};
+            $error .= qq{<div class="alert alert-danger">Unable to open module</div>};
         }
     } else {
-        $error = qq{Not a file or incorrect file path};
+        $error = qq{<div class="alert alert-danger">Not a file or incorrect file path</div>};
     }
     
 
@@ -390,14 +390,14 @@ sub _inc {
         my $out = $modules->_inc_dir( dir => "")
 
         <a 
-            href="http://loclhost:20202/_inc_dir/home/ns21u2204/perl5/perlbrew/perls/perl-5.38.0/lib/5.38.0/x86_64-linux"
+            href="http://loclhost:20202/_inc_dir//home/ns21u2204/perl5/perlbrew/perls/perl-5.38.0/lib/5.38.0/x86_64-linux"
             title="x86_64-linux"
         >
         x86_64-linux
         </a>
 
         <a 
-            href="http://CompanionUrl/_inc_dir/home/ns21u2204/p/perl/Perl-Modules-Companion/lib" 
+            href="http://CompanionUrl/_inc_dir//home/ns21u2204/p/perl/Perl-Modules-Companion/lib" 
             title="lib"
         >
         lib
